@@ -13,6 +13,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "utils/timecode.h"
 
 #include <KMessageWidget>
+#include <kddockwidgets/DockWidget.h>
 
 #include <QActionGroup>
 #include <QDir>
@@ -154,7 +155,7 @@ public:
 private:
     enum ItemRole { NameRole = Qt::UserRole, DurationRole, UsageRole };
 
-    QTimeLine *m_timeLine;
+    QTimeLine *m_timeLine{nullptr};
     QAction *m_action{nullptr};
     QMutex m_locker;
 
@@ -199,6 +200,13 @@ public:
     explicit Bin(std::shared_ptr<ProjectItemModel> model, QWidget *parent = nullptr, bool isMainBin = true, BinViewType type = BinUnknownView);
     ~Bin() override;
 
+    struct ClipZoneInfo
+    {
+        QString clipId;
+        QPoint zone;
+        int seekFrame;
+    };
+
     bool isLoading;
     /** @brief Sets the document for the bin and initialize some stuff  */
     const QString setDocument(KdenliveDoc *project, const QString &id = QString());
@@ -274,6 +282,9 @@ public:
     void blockBin(bool block);
     void doMoveFolder(const QString &id, const QString &newParentId);
     void setupGeneratorMenu();
+    QMenu *addClipMenu() const;
+    void setReadyCallBack(const std::function<void(const QString &)> &cb);
+    void setSuggestedDuration(int duration);
     void clearMonitor();
 
     /** @brief Set focus to the Bin view. */
@@ -310,7 +321,7 @@ public:
     /** @brief Get usage stats for project bin. */
     void getBinStats(uint *used, uint *unused, qint64 *usedSize, qint64 *unusedSize);
     /** @brief Returns the clip properties dockwidget. */
-    QDockWidget *clipPropertiesDock();
+    KDDockWidgets::QtWidgets::DockWidget *clipPropertiesDock();
     void rebuildProxies();
     /** @brief Return a list of all clips hashes used in this project */
     QStringList getProxyHashList();
@@ -320,6 +331,10 @@ public:
     void saveZone(const QStringList &info, const QDir &dir);
     /** @brief A bin clip changed (its effects), invalidate preview */
     void invalidateClip(const QString &binId);
+    /** @brief A bin clip changed (its effects), invalidate audio preview */
+    void invalidateClipAudio(const QString &binId);
+    /** @brief Update sequence audio thumb if necessary */
+    void rebuildAudioThumb(const QString &binId);
     /** @brief Recreate missing proxies on document opening */
     void checkMissingProxies();
     /** @brief Save folder state (expanded or not) */
@@ -397,8 +412,15 @@ public:
     /** @brief Expand / collapse all items */
     void expandAll();
     bool isMainBin() const;
+    void buildPropertiesDock(KDDockWidgets::QtWidgets::DockWidget *parentDock);
+    const QString slotAddClipToProject(const QUrl &url);
+    /** @brief Save all sequence audio thumbnails to disk */
+    void saveSequenceAudioThumb();
+    /** @brief Generate or load all sequence audio thumbnails from disk */
+    void loadSequenceAudioThumb();
 
-private Q_SLOTS:
+public Q_SLOTS:
+    const QString slotUrlsDropped(const QList<QUrl> urls, const QModelIndex parent);
     void slotAddClip();
     /** @brief Reload clip from disk */
     void slotReloadClip();
@@ -467,7 +489,7 @@ private Q_SLOTS:
     /** @brief Open a new Bin widget */
     void slotOpenNewBin();
     /** @brief Open clip in monitor */
-    void openClipInMonitor(std::shared_ptr<ProjectClip> clip, int in = -1, int out = -1, const QUuid &uuid = QUuid());
+    void openClipInMonitor(std::shared_ptr<ProjectClip> clip, int in = -1, int out = -1, const QUuid &uuid = QUuid(), int seekFrame = -1);
     /** @brief Perform the drag */
     bool performDrag(const QModelIndexList indexes);
 
@@ -486,7 +508,6 @@ public Q_SLOTS:
     void slotStartFilterJob(/*const ItemInfo &info,*/ const QString &id, QMap<QString, QString> &filterParams, QMap<QString, QString> &consumerParams,
                             QMap<QString, QString> &extraParams);
     void slotItemDropped(const QStringList ids, const QModelIndex parent, bool dropFromSameSource);
-    const QString slotUrlsDropped(const QList<QUrl> urls, const QModelIndex parent);
     void slotEffectDropped(const QStringList &effectData, const QModelIndex &parent);
     void slotTagDropped(const QString &tag, const QModelIndex &parent);
     void slotItemEdited(const QModelIndex &, const QModelIndex &, const QVector<int> &);
@@ -508,7 +529,6 @@ public Q_SLOTS:
     void doDisplayMessage(const QString &text, KMessageWidget::MessageType type, const QString logInfo);
     /** @brief Select a clip in the Bin from its id. */
     void selectClipById(const QString &id, int frame = -1, const QPoint &zone = QPoint(), bool activateMonitor = true);
-    const QString slotAddClipToProject(const QUrl &url);
     void droppedUrls(const QList<QUrl> &urls, const QString &folderInfo = QString());
     /** @brief Adjust project profile to current clip. */
     void adjustProjectProfileToItem();
@@ -573,7 +593,7 @@ private:
     /** @brief Keeps the column width info of the tree view. */
     QByteArray m_headerInfo;
     QVBoxLayout *m_layout;
-    QDockWidget *m_propertiesDock;
+    KDDockWidgets::QtWidgets::DockWidget *m_propertiesDock;
     QScrollArea *m_propertiesPanel;
     QSlider *m_slider;
     QIcon m_blankThumb;
@@ -600,7 +620,7 @@ private:
     QAction *m_upAction{nullptr};
     QAction *m_tagAction{nullptr};
     QActionGroup *m_sortGroup{nullptr};
-    SmallJobLabel *m_infoLabel;
+    SmallJobLabel *m_infoLabel{nullptr};
     TagWidget *m_tagsWidget;
     QMenu *m_filterMenu{nullptr};
     QActionGroup m_filterTagGroup;
@@ -631,6 +651,8 @@ private:
     long m_processedAudio;
     /** @brief Indicates whether audio thumbnail creation is running. */
     QFuture<void> m_audioThumbsThread;
+    std::function<void(const QString &)> m_readyCallBack;
+    int m_suggestedDuration{-1};
     QAction *addBinAction(const QString &name, const QString &text, const QIcon &icon, const QString &category = {});
     void setupAddClipAction(QMenu *addClipMenu, ClipType::ProducerType type, const QString &name, const QString &text, const QIcon &icon);
     /** @brief Get the QModelIndex value for an item in the Bin. */
@@ -641,6 +663,7 @@ private:
     int wheelAccumulatedDelta;
     QString m_keyBindingMessage;
     QString m_clipsCountMessage;
+    ClipZoneInfo m_activateClipZoneInfo;
     /** @brief Show the clip count and key binfing info in status bar. */
     void showBinInfo();
     /** @brief Find all clip Ids that have a specific tag. */
@@ -661,7 +684,7 @@ Q_SIGNALS:
     void requesteInvalidRemoval(const QString &, const QString &, const QString &);
     /** @brief Analysis data changed, refresh panel. */
     void updateAnalysisData(const QString &);
-    void openClip(std::shared_ptr<ProjectClip> c, int in = -1, int out = -1, const QUuid sequenceUuid = QUuid());
+    void openClip(std::shared_ptr<ProjectClip> c, int in = -1, int out = -1, const QUuid sequenceUuid = QUuid(), int seekFrame = -1);
     /** @brief Fill context menu with occurrences of this clip in timeline. */
     void findInTimeline(const QString &, QList<int> ids = QList<int>());
     void clipNameChanged(int, const QString);
@@ -672,6 +695,7 @@ Q_SIGNALS:
     void requestBinClose();
     /** @brief Update a timeline tab name on clip rename. */
     void updateTabName(const QUuid &, const QString &);
+    void requestAddClipReset();
     /** @brief Some timeline sequence producers have been updated, refresh their occurrences. */
     void requestUpdateSequences(QMap<QUuid, std::pair<int, int>> seqs);
 };
