@@ -8,6 +8,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "definitions.h"
 #include "jobs/taskmanager.h"
 #include "kdenlivecore_export.h"
+#include "layouts/layoutinfo.h"
 #include "undohelper.hpp"
 #include "utils/timecode.h"
 
@@ -41,6 +42,7 @@ class MonitorManager;
 class ProfileModel;
 class ProjectItemModel;
 class ProjectManager;
+class Splash;
 class SubtitleEdit;
 class SubtitleModel;
 class TextBasedEdit;
@@ -87,7 +89,7 @@ public:
      * with Mlt
      * @param MltPath (optional) path to MLT environment
      */
-    static bool build(LinuxPackageType packageType, bool testMode = false, bool debugMode = false);
+    static bool build(LinuxPackageType packageType, bool testMode = false, bool debugMode = false, bool showWelcome = true);
 
     void initHeadless(const QUrl &url);
 
@@ -224,6 +226,10 @@ public:
     /** @brief Mark an item as invalid for timeline preview */
     void invalidateItem(ObjectId itemId);
     void invalidateRange(QPair<int, int> range);
+    /** @brief Mark an item audio as invalid for timeline preview */
+    void invalidateAudio(ObjectId itemId);
+    /** @brief Mark an audio range as invalid for timeline preview */
+    void invalidateAudioRange(const QUuid &uuid, int in, int out);
     void prepareShutdown();
     void finishShutdown();
     /** the keyframe model changed (effect added, deleted, active effect changed), inform timeline */
@@ -305,6 +311,8 @@ public:
     void clearTimeRemap();
     /** @brief Create the dock widgets */
     void buildDocks();
+    /** @brief Restore the default app layout */
+    void restoreLayout();
     /** @brief Get the frame size of the clip above a composition */
     const QSize getCompositionSizeOnTrack(const ObjectId &id);
     void loadTimelinePreview(const QUuid uuid, const QString &chunks, const QString &dirty, bool enablePreview, Mlt::Playlist &playlist);
@@ -356,6 +364,17 @@ public:
     int currentTimelineOffset();
     /** HW decoder changed */
     void updateHwDecoding();
+    /** Close the application */
+    void closeApp();
+
+    void startHideBarsTimer();
+    void updateHideBarsTimer(bool inhibit);
+    /** @brief This is the producer that serves as a placeholder while a clip is being loaded. It is created in Core at startup */
+    std::unique_ptr<Mlt::Producer> mediaUnavailable;
+    /** @brief Returns true if the project uses a vertical profile */
+    bool isVertical() const;
+    /** @brief Returns a list of luma files compatible with current project profile */
+    const QStringList getLumasForProfile();
 
 private:
     explicit Core(LinuxPackageType packageType, bool debugMode = false);
@@ -387,12 +406,22 @@ private:
     Mlt::Profile m_monitorProfile;
     /** @brief Mlt profile used to build the project's clips */
     Mlt::Profile m_projectProfile;
-    bool m_guiConstructed = false;
+    bool m_guiConstructed{false};
+    bool m_abortInitAndRestart{false};
+    Splash *m_splash{nullptr};
+    QEventLoop m_loop;
     /** @brief Check that the profile is valid (width is a multiple of 8 and height a multiple of 2 */
     void checkProfileValidity();
     std::shared_ptr<MediaCapture> m_capture;
     QUrl m_mediaCaptureFile;
+    QTimer m_hideTimer;
     void resetThumbProfile();
+    /** @brief Build the Splash Screen.
+     *  @param firstRun if true, we display the First start Quick Config dialog
+     *  @param showWelcome if true, display the welcome screen. If false, a simple splash screen
+     *  @param showCrashRecovery if true, always display the crash recovery option
+     *  @param wasUpgraded if true, show a short upgrade message */
+    void buildSplash(bool firstRun, bool showWelcome, bool showCrashRecovery, bool wasUpgraded);
 
 protected:
     /** @brief A unique session id for this app instance */
@@ -438,12 +467,15 @@ public Q_SLOTS:
     void monitorAudio(int tid, bool monitor);
     /** @brief Open a documentation link, showing a warning box first */
     void openDocumentationLink(const QUrl &link);
+    void openLink(const QUrl &link);
 
 private Q_SLOTS:
     /** @brief display a user info/warning message in the project bin */
     void displayBinMessagePrivate(const QString &text, int type, const QList<QAction *> &actions = QList<QAction *>(), bool showClose = false,
                                   BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
     void displayBinLogMessagePrivate(const QString &text, int type, const QString logInfo);
+    void cleanRestart(bool cleanAndRestart);
+    void startFromGuessedProfile(QString descriptiveString, QString fps, bool interlaced, int vTracks, int aTracks);
 
 Q_SIGNALS:
     void coreIsReady();
@@ -453,6 +485,7 @@ Q_SIGNALS:
     void showConfigDialog(Kdenlive::ConfigPage, int);
     void finalizeRecording(const QUuid uuid, const QString &captureFile);
     void autoScrollChanged();
+    void centeredPlayheadChanged();
     /** @brief Update the message about the current loading progress */
     void loadingMessageNewStage(const QString &message, int max = -1);
     /** @brief Increase the progress of the loading message by 1 */
@@ -526,4 +559,14 @@ Q_SIGNALS:
     void displayBinLogMessage(const QString &text, int type, const QString logInfo);
     /** Some properties related to rendering changed, update */
     void updateRenderOffset();
+    void hideBars(bool);
+    void switchTitleBars();
+    void loadLayoutById(QString layoutId, bool onlyIfNoPrevious = false);
+    void switchDarkPalette(bool dark);
+    void mainWindowReady();
+    void loadLayoutFromData(const QString layout, bool onlyIfNoPrevious = false);
+    /** The project profile changed, check if we have a more appropriate layout (horizontal/vertical) */
+    void adjustLayoutToDar();
+    /** Should be called when the mainwindow has been constructed and before any dialog is shown to hide the splash screen */
+    void GUISetupDone();
 };
