@@ -13,6 +13,7 @@
 */
 
 #include "monitor/monitor.h"
+#include "monitor/view/qmliconprovider.hpp"
 #include <QApplication>
 #include <QFontDatabase>
 #include <QOpenGLContext>
@@ -24,6 +25,7 @@
 #include <QPainter>
 #include <QQmlContext>
 #include <QQuickItem>
+#include <QStyle>
 #include <QtGlobal>
 #include <memory>
 
@@ -132,11 +134,16 @@ VideoWidget::VideoWidget(int id, QObject *parent)
     m_proxy = new MonitorProxy(this);
     rootContext()->setContextProperty("controller", m_proxy);
     engine()->addImageProvider(QStringLiteral("thumbnail"), new ThumbnailProvider);
+    int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize);
+    engine()->addImageProvider(QStringLiteral("icon"), new QmlIconProvider(QSize(iconSize, iconSize), this));
+    m_mouseTimer.setSingleShot(true);
+    m_mouseTimer.setInterval(2000);
 }
 
 VideoWidget::~VideoWidget()
 {
     stop();
+    m_mouseTimer.stop();
     if (m_frameRenderer && m_frameRenderer->isRunning()) {
         m_frameRenderer->quit();
         m_frameRenderer->wait();
@@ -145,6 +152,23 @@ VideoWidget::~VideoWidget()
     m_blackClip.reset();
 }
 
+void VideoWidget::enableMouseTimer(bool enable)
+{
+    m_fullScreen = enable;
+    if (enable) {
+        connect(&m_mouseTimer, &QTimer::timeout, this, &VideoWidget::blankCursor, Qt::UniqueConnection);
+    } else {
+        m_mouseTimer.stop();
+        setCursor(Qt::ArrowCursor);
+        disconnect(&m_mouseTimer, &QTimer::timeout, this, &VideoWidget::blankCursor);
+    }
+}
+
+void VideoWidget::blankCursor()
+{
+    setCursor(Qt::BlankCursor);
+}
+
 void VideoWidget::updateAudioForAnalysis()
 {
     if (m_frameRenderer) {
@@ -193,6 +217,11 @@ const QStringList VideoWidget::getGPUInfo()
     return {};
 }
 
+void VideoWidget::setFixedImageSize(const QSize fixedSize)
+{
+    m_fixedSize = fixedSize;
+}
+
 void VideoWidget::resizeVideo(int width, int height)
 {
     double x, y, w, h;
@@ -201,21 +230,28 @@ void VideoWidget::resizeVideo(int width, int height)
 
     // Special case optimization to negate odd effect of sample aspect ratio
     // not corresponding exactly with image resolution.
-    if (int(this_aspect * 1000) == int(m_dar * 1000)) {
-        w = width;
-        h = height;
-    }
-    // Use OpenGL to normalise sample aspect ratio
-    else if (height * m_dar > width) {
-        w = width;
-        h = width / m_dar;
+    if (m_fixedSize.isValid()) {
+        w = m_fixedSize.width();
+        h = m_fixedSize.height();
     } else {
-        w = height * m_dar;
-        h = height;
+        if (int(this_aspect * 1000) == int(m_dar * 1000)) {
+            w = width;
+            h = height;
+        }
+        // Use OpenGL to normalise sample aspect ratio
+        else if (height * m_dar > width) {
+            w = width;
+            h = width / m_dar;
+        } else {
+            w = height * m_dar;
+            h = height;
+        }
     }
     x = (width - w) / 2.0;
     y = (height - h) / 2.0;
     m_rect = QRectF(x, y, w, h);
+    const QSize parentSize = parentWidget()->size();
+    m_monitorOffset = QPointF((parentSize.width() - width) / 2., (parentSize.height() - m_displayRulerHeight - height) / 2.);
 
     QQuickItem *rootQml = rootObject();
     if (rootQml) {
@@ -242,6 +278,13 @@ void VideoWidget::resizeEvent(QResizeEvent *event)
     resizeVideo(event->size().width(), event->size().height());
 }
 
+void VideoWidget::updateImagePosition()
+{
+    if (m_fixedSize.isValid()) {
+        resizeVideo(width(), height());
+    }
+}
+
 void VideoWidget::forceRefreshZoom()
 {
     setZoom(m_zoom, true);
@@ -288,6 +331,11 @@ void VideoWidget::slotZoom(bool zoomIn)
     }
 }
 
+void VideoWidget::slotZoomReset()
+{
+    setZoom(1.);
+}
+
 void VideoWidget::refreshRect()
 {
     resizeVideo(width(), height());
@@ -404,28 +452,32 @@ bool VideoWidget::checkFrameNumber(int pos, bool isPlaying)
 
 void VideoWidget::mousePressEvent(QMouseEvent *event)
 {
-    if ((rootObject() != nullptr) && rootObject()->property("captureRightClick").toBool() && !(event->modifiers() & Qt::ControlModifier) &&
-        !(event->buttons() & Qt::MiddleButton)) {
-        event->ignore();
-        QQuickWidget::mousePressEvent(event);
-        return;
+    if (m_fullScreen) {
+        if (!m_mouseTimer.isActive()) {
+            setCursor(Qt::ArrowCursor);
+        } else {
+            m_mouseTimer.stop();
+        }
     }
     QQuickWidget::mousePressEvent(event);
     // For some reason, on Qt6 in mouseReleaseEvent, the event is always accepted, so use this m_qmlEvent bool to track if the event is accepted in qml
     m_qmlEvent = event->isAccepted();
-    if (rootObject() != nullptr && rootObject()->property("captureRightClick").toBool()) {
+    m_dragStart = QPoint();
+    if (rootObject() != nullptr && m_qmlEvent && rootObject()->property("captureRightClick").toBool()) {
         // The event has been handled in qml
         m_swallowDrop = true;
+    } else {
+        m_swallowDrop = false;
     }
     if ((event->button() & Qt::LeftButton) != 0u) {
         if ((event->modifiers() & Qt::ControlModifier) != 0u) {
             // Pan view
             m_panStart = event->pos();
             setCursor(Qt::ClosedHandCursor);
-        } else {
+        } else if (getControllerProxy()->dragType() != QLatin1String("-")) {
             m_dragStart = event->pos();
         }
-    } else if ((event->button() & Qt::RightButton) != 0u) {
+    } else if ((event->button() & Qt::RightButton) != 0u && !m_swallowDrop) {
         Q_EMIT showContextMenu(event->globalPosition().toPoint());
     } else if ((event->button() & Qt::MiddleButton) != 0u) {
         m_panStart = event->pos();
@@ -433,18 +485,50 @@ void VideoWidget::mousePressEvent(QMouseEvent *event)
     }
 }
 
+void VideoWidget::focusInEvent(QFocusEvent *event)
+{
+    if (m_fullScreen) {
+        if (!m_mouseTimer.isActive()) {
+            setCursor(Qt::ArrowCursor);
+        }
+        if (parentWidget()->isFullScreen()) {
+            m_mouseTimer.start();
+        }
+    }
+    QQuickWidget::focusInEvent(event);
+}
+
+void VideoWidget::focusOutEvent(QFocusEvent *event)
+{
+    if (m_fullScreen) {
+        if (!m_mouseTimer.isActive()) {
+            setCursor(Qt::ArrowCursor);
+        }
+        m_mouseTimer.stop();
+    }
+    QQuickWidget::focusOutEvent(event);
+}
+
 void VideoWidget::mouseReleaseEvent(QMouseEvent *event)
 {
+    if (m_fullScreen) {
+        m_mouseTimer.start();
+    }
+    bool qmlClick = rootObject()->property("captureRightClick").toBool();
     QQuickWidget::mouseReleaseEvent(event);
-    bool playMonitor = KdenliveSettings::play_monitor_on_click() && !m_dragStart.isNull() && m_panStart.isNull();
+    rootObject()->setProperty("captureRightClick", false);
+    bool playMonitor = KdenliveSettings::play_monitor_on_click() &&
+                       (m_dragStart.isNull() || (event->pos() - m_dragStart).manhattanLength() < QApplication::startDragDistance()) && m_panStart.isNull();
+
     m_dragStart = QPoint();
     m_panStart = QPoint();
     setCursor(Qt::ArrowCursor);
     if (event->modifiers() & Qt::ControlModifier || m_qmlEvent) {
         event->accept();
+        m_swallowDrop = false;
         return;
     }
-    if (playMonitor && ((event->button() & Qt::LeftButton) != 0u) && !m_swallowDrop) {
+    if (playMonitor && ((event->button() & Qt::LeftButton) != 0u) && !m_swallowDrop && !qmlClick) {
         event->accept();
         Q_EMIT monitorPlay();
     }
@@ -453,6 +537,12 @@ void VideoWidget::mouseReleaseEvent(QMouseEvent *event)
 
 void VideoWidget::mouseMoveEvent(QMouseEvent *event)
 {
+    if (m_fullScreen) {
+        if (!m_mouseTimer.isActive()) {
+            setCursor(Qt::ArrowCursor);
+        }
+        m_mouseTimer.start();
+    }
     if ((rootObject() != nullptr) && rootObject()->objectName() != QLatin1String("root") && !(event->modifiers() & Qt::ControlModifier) &&
         !(event->buttons() & Qt::MiddleButton)) {
         event->ignore();
@@ -471,7 +561,7 @@ void VideoWidget::mouseMoveEvent(QMouseEvent *event)
         return;
     }
 
-    if (!event->isAccepted() && !m_dragStart.isNull() && (event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) {
+    if (!m_dragStart.isNull() && (event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) {
         m_dragStart = QPoint();
         Q_EMIT startDrag();
     }
@@ -638,7 +728,7 @@ int VideoWidget::setProducer(const std::shared_ptr<Mlt::Producer> &producer, boo
     }
     m_consumer->set("scrub_audio", 0);
     if (position != -2) {
-        m_proxy->setPositionAdvanced(position > 0 ? position : m_producer->position(), true);
+        m_proxy->setPositionAdvanced(position >= 0 ? position : m_producer->position(), true);
     }
     return error;
 }
@@ -648,14 +738,14 @@ bool VideoWidget::isPaused() const
     return m_producer && qAbs(m_producer->get_speed()) < 0.1;
 }
 
-void VideoWidget::pause(int position)
+void VideoWidget::pause()
 {
-    if (m_producer && !isPaused()) {
+    int position = m_consumer ? m_consumer->position() + 1 : -1;
+    if (m_producer && (!isPaused() || (m_maxProducerPosition - position < 25))) {
         Q_EMIT paused();
         m_producer->set_speed(0);
         if (m_consumer && m_consumer->is_valid()) {
             m_consumer->set("volume", 0);
-            position = position > -1 ? position : m_consumer->position() + 1;
             m_producer->seek(position);
             m_consumer->purge();
             m_consumer->start();
@@ -812,10 +902,25 @@ int VideoWidget::reconfigure()
         m_consumer->set("prefill", 6);
         m_consumer->set("drop_max", fps / 4);
         m_consumer->set("scrub_audio", KdenliveSettings::audio_scrub());
-        if (KdenliveSettings::monitor_gamma() == 0) {
-            m_consumer->set("color_trc", "iec61966_2_1");
-        } else {
+        switch (pCore->getProjectProfile().colorspace()) {
+        case 601:
+        case 170:
+            m_consumer->set("color_trc", "smpte170m");
+            break;
+        case 240:
+            m_consumer->set("color_trc", "smpte240m");
+            break;
+        case 470:
+            m_consumer->set("color_trc", "bt470bg");
+            break;
+        case 2020:
+            // if (isDeckLinkHLG) {
+            //     m_consumer->set("color_trc", "arib-std-b67");
+            m_consumer->clear("color_trc");
+            break;
+        default:
             m_consumer->set("color_trc", "bt709");
+            break;
         }
     } else {
         // Cleanup on error
@@ -1088,7 +1193,6 @@ bool VideoWidget::switchPlay(bool play, double speed)
                 return false;
             }
         }
-        qDebug() << "pos: " << m_consumer->position() << "out: " << m_producer->get_playtime() - 1;
         double current_speed = m_producer->get_speed();
         m_producer->set_speed(speed);
         m_proxy->setSpeed(speed);
@@ -1098,6 +1202,11 @@ bool VideoWidget::switchPlay(bool play, double speed)
             m_consumer->set("scrub_audio", 1);
         }
         if (qFuzzyIsNull(current_speed)) {
+            if (m_maxProducerPosition - m_consumer->position() < 6) {
+                m_consumer->set("prefill", 1);
+            } else {
+                m_consumer->set("prefill", 6);
+            }
             m_consumer->start();
             m_consumer->set("refresh", 1);
             m_consumer->set("volume", KdenliveSettings::volume() / 100.);
