@@ -260,6 +260,7 @@ QHash<int, QByteArray> TimelineItemModel::roleNames() const
     roles[StartRole] = "start";
     roles[MixRole] = "mixDuration";
     roles[MixCutRole] = "mixCut";
+    roles[MixEndDurationRole] = "mixEndDuration";
     roles[DurationRole] = "duration";
     roles[MaxDurationRole] = "maxDuration";
     roles[MarkersRole] = "markers";
@@ -280,6 +281,7 @@ QHash<int, QByteArray> TimelineItemModel::roleNames() const
     roles[AudioStreamIndexRole] = "audioStreamIndex";
     roles[IsCompositeRole] = "composite";
     roles[IsLockedRole] = "locked";
+    roles[IsHiddenRole] = "hideItem";
     roles[FadeInRole] = "fadeIn";
     roles[FadeOutRole] = "fadeOut";
     roles[FadeInMethodRole] = "fadeInMethod";
@@ -410,6 +412,8 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
             return clip->getMixDuration();
         case MixCutRole:
             return clip->getMixCutPosition();
+        case MixEndDurationRole:
+            return getEndMixDuration(id);
         case ClipThumbRole:
             return clip->clipThumbPath();
         case ReloadAudioThumbRole:
@@ -512,6 +516,8 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
             return compo->showKeyframes();
         case ItemATrack:
             return compo->getForcedTrack();
+        case IsHiddenRole:
+            return compo->isHidden();
         case MarkersRole: {
             QVariantList markersList;
             return markersList;
@@ -563,10 +569,14 @@ void TimelineItemModel::setTrackProperty(int trackId, const QString &name, const
         roles.push_back(IsLockedRole);
     } else if (name == QLatin1String("hide")) {
         roles.push_back(IsDisabledRole);
-        if (!track->isAudioTrack() && !isLoading) {
-            pCore->invalidateItem(ObjectId(KdenliveObjectType::TimelineTrack, trackId, m_uuid));
-            pCore->refreshProjectMonitorOnce();
-            updateMultiTrack = true;
+        if (!isLoading) {
+            if (!track->isAudioTrack()) {
+                pCore->invalidateItem(ObjectId(KdenliveObjectType::TimelineTrack, trackId, m_uuid));
+                pCore->refreshProjectMonitorOnce();
+                updateMultiTrack = true;
+            } else {
+                pCore->invalidateAudio(ObjectId(KdenliveObjectType::TimelineTrack, trackId, m_uuid));
+            }
         }
     } else if (name == QLatin1String("kdenlive:timeline_active")) {
         roles.push_back(TrackActiveRole);
@@ -804,6 +814,9 @@ void TimelineItemModel::buildTrackCompositing(bool rebuild)
     QString composite;
     if (pCore->currentDoc()->getSequenceProperty(m_uuid, QStringLiteral("compositing"), QStringLiteral("1")).toInt() > 0) {
         composite = TransitionsRepository::get()->getCompositingTransition();
+        if (composite.isEmpty()) {
+            pCore->displayMessage(i18n("Could not setup track compositing, check your install"), MessageType::ErrorMessage);
+        }
     }
     int videoTracks = 0;
     int audioTracks = 0;
@@ -847,9 +860,6 @@ void TimelineItemModel::buildTrackCompositing(bool rebuild)
     if (isMultiTrack) {
         pCore->enableMultiTrack(true);
     }
-    if (composite.isEmpty()) {
-        pCore->displayMessage(i18n("Could not setup track compositing, check your install"), MessageType::ErrorMessage);
-    }
 }
 
 void TimelineItemModel::notifyChange(const QModelIndex &topleft, const QModelIndex &bottomright, int role)
@@ -1182,3 +1192,23 @@ QList<std::shared_ptr<KeyframeModelList>> TimelineItemModel::getGroupKeyframeMod
     }
     return models;
 }
+
+int TimelineItemModel::getEndMixDuration(int cid) const
+{
+    Q_ASSERT(isClip(cid));
+    int tid = m_allClips.at(cid)->getCurrentTrackId();
+    qDebug() << ":::: CHECKING MIX  FOR: " << cid;
+    if (tid > -1) {
+        MixInfo mixData = getTrackById_const(tid)->getMixInfo(cid).second;
+        if (mixData.secondClipId > -1) {
+            qDebug() << ":::: CLIP HAS END MIX WITH: " << mixData.secondClipId;
+            MixInfo mixData2 = getTrackById_const(tid)->getMixInfo(mixData.secondClipId).first;
+            qDebug() << ":::: GOT OFFSET DATA FOR CLIP: " << cid << " = " << mixData2.mixOffset;
+            return mixData2.firstClipInOut.second - mixData2.secondClipInOut.first;
+            // return {mixData.secondClipInOut.first, mixData.firstClipInOut.second};
+        } else {
+            qDebug() << ":::: CLIP HAS NO END MIX... FIRST MIX:" << getTrackById_const(tid)->getMixInfo(cid).first.firstClipId;
+        }
+    }
+    return 0;
+}
